The Claims Management Services Tribunal was created by the Compensation Act 2006 to hear appeals against decisions of the Claims Management Services Regulator and references from the Regulator concerning the professional conduct of persons providing claims management services. In 2010 its functions were transferred to the General Regulatory Chamber of the First-tier Tribunal, which hears appeals against decisions made by government regulatory bodies.

Looking for the original tribunal database: This is a historic tribunal. The functions of this tribunal have been transferred to the General Regulatory Chamber of the First-tier Tribunal. The GRC began transferring records to Find Case Law in 2022. To view an archived version of the decisions of this tribunal from 2009-2011 visit the UK Government Web Archive.
